@@ -12,7 +12,6 @@ from aasm.intermediate.argument import (
     ConnectionList,
     EnumValue,
     Float,
-    Literal,
     MessageList,
     ReceivedMessageParam,
     SendMessageParam,
@@ -526,9 +525,6 @@ class PythonSpadeCode(PythonCode):
                 prop = arg.expr.split(".")[1]
                 return f'send["{prop}"]'
 
-            case Connection() if isinstance(arg.type_in_op, Literal):
-                return f'"{arg.expr[1:]}"'
-
             case _:
                 return arg.expr
 
