@@ -16,11 +16,11 @@ class Constant(PreprocessorItem):
         self.value = value
 
     def expand(self, line: str) -> str:
-        tokens = [token.strip() for token in line.strip().replace(',', ' ').split()]
+        tokens = [token.strip() for token in line.strip().replace(",", " ").split()]
         tokens = [self.value if token == self.name else token for token in tokens]
         if len(tokens) < 2:
             return line
         new_line = tokens[0] + " "
         new_line = new_line + " ".join(tok + "," for tok in tokens[1:])
-        new_line = new_line.lstrip(',')
+        new_line = new_line.lstrip(",")
         return new_line
